@@ -67,7 +67,7 @@ xfpm_brightness_xrand_get_limit (XfpmBrightness *brightness, RROutput output, gi
     gboolean ret = TRUE;
 
     gdk_error_trap_push ();
-    info = XRRQueryOutputProperty (GDK_DISPLAY (), output, brightness->priv->backlight);
+    info = XRRQueryOutputProperty (gdk_x11_get_default_xdisplay (), output, brightness->priv->backlight);
     
     if (gdk_error_trap_pop () != 0
         || info == NULL)
@@ -92,17 +92,17 @@ out:
 }
 
 static gboolean
-xfpm_brightness_xrandr_get_level (XfpmBrightness *brightness, RROutput output, long *current)
+xfpm_brightness_xrandr_get_level (XfpmBrightness *brightness, RROutput output, gint32 *current)
 {
     unsigned long nitems;
     unsigned long bytes_after;
-    long *prop;
+    gint32 *prop;
     Atom actual_type;
     int actual_format;
     gboolean ret = FALSE;
 
     gdk_error_trap_push ();
-    if (XRRGetOutputProperty (GDK_DISPLAY (), output, brightness->priv->backlight,
+    if (XRRGetOutputProperty (gdk_x11_get_default_xdisplay (), output, brightness->priv->backlight,
 			      0, 4, False, False, None,
 			      &actual_type, &actual_format,
 			      &nitems, &bytes_after, ((unsigned char **)&prop)) != Success
@@ -124,20 +124,20 @@ xfpm_brightness_xrandr_get_level (XfpmBrightness *brightness, RROutput output, l
 }
 
 static gboolean
-xfpm_brightness_xrandr_set_level (XfpmBrightness *brightness, RROutput output, long level)
+xfpm_brightness_xrandr_set_level (XfpmBrightness *brightness, RROutput output, gint32 level)
 {
     gboolean ret = TRUE;
 
     gdk_error_trap_push ();
-    XRRChangeOutputProperty (GDK_DISPLAY (), output, brightness->priv->backlight, XA_INTEGER, 32,
+    XRRChangeOutputProperty (gdk_x11_get_default_xdisplay (), output, brightness->priv->backlight, XA_INTEGER, 32,
 			     PropModeReplace, (unsigned char *) &level, 1);
 			     
-    XFlush (GDK_DISPLAY ());
+    XFlush (gdk_x11_get_default_xdisplay ());
     gdk_flush ();
     
     if ( gdk_error_trap_pop () ) 
     {
-	    g_warning ("failed to XRRChangeOutputProperty for brightness %li", level);
+	    g_warning ("failed to XRRChangeOutputProperty for brightness %d", level);
 	    ret = FALSE;
     }
     
@@ -157,8 +157,8 @@ xfpm_brightness_setup_xrandr (XfpmBrightness *brightness)
     gint i;
     
     gdk_error_trap_push ();
-    if (!XRRQueryExtension (GDK_DISPLAY (), &event_base, &error_base) ||
-	!XRRQueryVersion (GDK_DISPLAY (), &major, &minor) )
+    if (!XRRQueryExtension (gdk_x11_get_default_xdisplay (), &event_base, &error_base) ||
+	!XRRQueryVersion (gdk_x11_get_default_xdisplay (), &major, &minor) )
     {
 	gdk_error_trap_pop ();
 	g_warning ("No XRANDR extension found");
@@ -173,10 +173,10 @@ xfpm_brightness_setup_xrandr (XfpmBrightness *brightness)
     }
     
 #ifdef RR_PROPERTY_BACKLIGHT
-    brightness->priv->backlight = XInternAtom (GDK_DISPLAY (), RR_PROPERTY_BACKLIGHT, True);
+    brightness->priv->backlight = XInternAtom (gdk_x11_get_default_xdisplay (), RR_PROPERTY_BACKLIGHT, True);
     if (brightness->priv->backlight == None) /* fall back to deprecated name */
 #endif
-    brightness->priv->backlight = XInternAtom (GDK_DISPLAY (), "BACKLIGHT", True);
+    brightness->priv->backlight = XInternAtom (gdk_x11_get_default_xdisplay (), "BACKLIGHT", True);
     
     if (brightness->priv->backlight == None) 
     {
@@ -190,18 +190,18 @@ xfpm_brightness_setup_xrandr (XfpmBrightness *brightness)
 
     gdk_error_trap_push ();
     
-    window = RootWindow (GDK_DISPLAY (), screen_num);
+    window = RootWindow (gdk_x11_get_default_xdisplay (), screen_num);
     
 #if (RANDR_MAJOR == 1 && RANDR_MINOR >=3 )
     if (major > 1 || minor >= 3)
-	brightness->priv->resource = XRRGetScreenResourcesCurrent (GDK_DISPLAY (), window);
+	brightness->priv->resource = XRRGetScreenResourcesCurrent (gdk_x11_get_default_xdisplay (), window);
     else
 #endif
-	brightness->priv->resource = XRRGetScreenResources (GDK_DISPLAY (), window);
+	brightness->priv->resource = XRRGetScreenResources (gdk_x11_get_default_xdisplay (), window);
 
     for ( i = 0; i < brightness->priv->resource->noutput; i++)
     {
-	info = XRRGetOutputInfo (GDK_DISPLAY (), brightness->priv->resource, brightness->priv->resource->outputs[i]);
+	info = XRRGetOutputInfo (gdk_x11_get_default_xdisplay (), brightness->priv->resource, brightness->priv->resource->outputs[i]);
 
 	if ( g_str_has_prefix (info->name, "LVDS") )
 	{
@@ -225,11 +225,11 @@ xfpm_brightness_setup_xrandr (XfpmBrightness *brightness)
 }
 
 static gboolean
-xfpm_brightness_xrand_up (XfpmBrightness *brightness, glong *new_level)
+xfpm_brightness_xrand_up (XfpmBrightness *brightness, gint32 *new_level)
 {
-    long hw_level;
+    gint32 hw_level;
     gboolean ret = FALSE;
-    long set_level;
+    gint32 set_level;
     
     ret = xfpm_brightness_xrandr_get_level (brightness, brightness->priv->output, &hw_level);
     
@@ -250,14 +250,14 @@ xfpm_brightness_xrand_up (XfpmBrightness *brightness, glong *new_level)
     
     if ( !ret )
     {
-	g_warning ("xfpm_brightness_xrand_up failed for %li", set_level);
+	g_warning ("xfpm_brightness_xrand_up failed for %d", set_level);
 	return FALSE;
     }
 	
     /* Nothing changed in the hardware*/
     if ( *new_level == hw_level )
     {
-	g_warning ("xfpm_brightness_xrand_up did not change the hw level to %li", set_level);
+	g_warning ("xfpm_brightness_xrand_up did not change the hw level to %d", set_level);
 	return FALSE;
     }
     
@@ -265,11 +265,11 @@ xfpm_brightness_xrand_up (XfpmBrightness *brightness, glong *new_level)
 }
 
 static gboolean
-xfpm_brightness_xrand_down (XfpmBrightness *brightness, long *new_level)
+xfpm_brightness_xrand_down (XfpmBrightness *brightness, gint32 *new_level)
 {
-    long hw_level;
+    gint32 hw_level;
     gboolean ret;
-    long set_level;
+    gint32 set_level;
     
     ret = xfpm_brightness_xrandr_get_level (brightness, brightness->priv->output, &hw_level);
     
@@ -290,14 +290,14 @@ xfpm_brightness_xrand_down (XfpmBrightness *brightness, long *new_level)
     
     if ( !ret )
     {
-	g_warning ("xfpm_brightness_xrand_down failed for %li", set_level);
+	g_warning ("xfpm_brightness_xrand_down failed for %d", set_level);
 	return FALSE;
     }
     
     /* Nothing changed in the hardware*/
     if ( *new_level == hw_level )
     {
-	g_warning ("xfpm_brightness_xrand_down did not change the hw level to %li", set_level);
+	g_warning ("xfpm_brightness_xrand_down did not change the hw level to %d", set_level);
 	return FALSE;
     }
     
@@ -361,7 +361,7 @@ xfpm_brightness_setup_helper (XfpmBrightness *brightness)
 }
 
 static gboolean
-xfpm_brightness_helper_get_level (XfpmBrightness *brg, glong *level)
+xfpm_brightness_helper_get_level (XfpmBrightness *brg, gint32 *level)
 {
     int ret;
 
@@ -406,11 +406,11 @@ out:
 }
 
 static gboolean
-xfpm_brightness_helper_up (XfpmBrightness *brightness, glong *new_level)
+xfpm_brightness_helper_up (XfpmBrightness *brightness, gint32 *new_level)
 {
-    glong hw_level;
+    gint32 hw_level;
     gboolean ret = FALSE;
-    gint set_level;
+    gint32 set_level;
     
     ret = xfpm_brightness_helper_get_level (brightness, &hw_level);
     
@@ -446,11 +446,11 @@ xfpm_brightness_helper_up (XfpmBrightness *brightness, glong *new_level)
 }
 
 static gboolean
-xfpm_brightness_helper_down (XfpmBrightness *brightness, glong *new_level)
+xfpm_brightness_helper_down (XfpmBrightness *brightness, gint32 *new_level)
 {
-    glong hw_level;
+    gint32 hw_level;
     gboolean ret;
-    gint set_level;
+    gint32 set_level;
     
     ret = xfpm_brightness_helper_get_level (brightness, &hw_level);
     
@@ -572,7 +572,7 @@ xfpm_brightness_setup (XfpmBrightness *brightness)
     return FALSE;
 }
 
-gboolean xfpm_brightness_up (XfpmBrightness *brightness, glong *new_level)
+gboolean xfpm_brightness_up (XfpmBrightness *brightness, gint32 *new_level)
 {
     gboolean ret = FALSE;
     
@@ -589,7 +589,7 @@ gboolean xfpm_brightness_up (XfpmBrightness *brightness, glong *new_level)
     return ret;
 }
 
-gboolean xfpm_brightness_down (XfpmBrightness *brightness, glong *new_level)
+gboolean xfpm_brightness_down (XfpmBrightness *brightness, gint32 *new_level)
 {
     gboolean ret = FALSE;
     
@@ -618,7 +618,7 @@ gint xfpm_brightness_get_max_level (XfpmBrightness *brightness)
     return brightness->priv->max_level;
 }
 
-gboolean xfpm_brightness_get_level	(XfpmBrightness *brightness, glong *level)
+gboolean xfpm_brightness_get_level	(XfpmBrightness *brightness, gint32 *level)
 {
     gboolean ret = FALSE;
     
@@ -632,7 +632,7 @@ gboolean xfpm_brightness_get_level	(XfpmBrightness *brightness, glong *level)
     return ret;
 }
 
-gboolean xfpm_brightness_set_level (XfpmBrightness *brightness, glong level)
+gboolean xfpm_brightness_set_level (XfpmBrightness *brightness, gint32 level)
 {
     gboolean ret = FALSE;
     
