@@ -25,28 +25,25 @@ G_BEGIN_DECLS
 
 #define XFPM_AC_ADAPTER_ICON			"xfpm-ac-adapter"
 
-#define XFPM_BATTERY_ICON			"battery"
 #define XFPM_UPS_ICON				"xfpm-ups-100"
 #define XFPM_KBD_ICON				"xfpm-keyboard-100"
 #define XFPM_MOUSE_ICON				"xfpm-mouse-100"
 #define XFPM_PHONE_ICON				"xfpm-phone-100"
 #define XFPM_PDA_ICON				"xfpm-pda-100"
 
-#define XFPM_PROCESSOR_ICON			"processor"
-
 #define XFPM_PRIMARY_ICON_PREFIX		"xfpm-primary-"
 #define XFPM_UPS_ICON_PREFIX			"xfpm-ups-"
 #define XFPM_MOUSE_ICON_PREFIX			"xfpm-mouse-"
 #define XFPM_KBD_ICON_PREFIX			"xfpm-keyboard-"
-#define XFPM_CAMERA_ICON_PREFIX			"xfpm-camera-"
 #define XFPM_PDA_ICON_PREFIX			"xfpm-pda-"
 #define XFPM_PHONE_ICON_PREFIX			"xfpm-phone-"
-#define XFPM_KBD_MOUSE_ICON_PREFIX		"xfpm-keyboard-mouse-"
+#define XFPM_MEDIA_PLAYER_PREFIX        "xfpm-mediaplayer-"
+#define XFPM_MONITOR_PREFIX             "xfpm-monitor-"
+#define XFPM_COMPUTER_ICON_PREFIX       "xfpm-computer-"
+#define XFPM_TABLET_ICON_PREFIX         "xfpm-tablet-"
 
 #define XFPM_DISPLAY_BRIGHTNESS_ICON	        "xfpm-brightness-lcd"
-#define XFPM_DISPLAY_BRIGHTNESS_INVALID_ICON	"xfpm-brightness-lcd-invalid" /* When no hw found */
-#define XFPM_HIBERNATE_ICON			"xfpm-hibernate"
-#define XFPM_SUSPEND_ICON			"xfpm-suspend"
+#define XFPM_DISPLAY_BRIGHTNESS_INVALID_ICON	"xfpm-brightness-lcd-missing" /* When no hw found */
 
 G_END_DECLS
 
