@@ -23,10 +23,15 @@
 #endif
 
 #include <stdio.h>
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
-
+#endif
+#ifdef HAVE_MATH_H
 #include <math.h>
+#endif
 
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
@@ -42,14 +47,9 @@
 #include "xfpm-debug.h"
 #include "xfpm-icons.h"
 
-#include "gsd-media-keys-window.h"
-
 static void xfpm_backlight_finalize     (GObject *object);
 
-static void xfpm_backlight_create_popup (XfpmBacklight *backlight);
-
 #define ALARM_DISABLED 9
-#define BRIGHTNESS_POPUP_SIZE	180
 
 #define XFPM_BACKLIGHT_GET_PRIVATE(o) \
 (G_TYPE_INSTANCE_GET_PRIVATE ((o), XFPM_TYPE_BACKLIGHT, XfpmBacklightPrivate))
@@ -63,17 +63,13 @@ struct XfpmBacklightPrivate
     XfpmButton     *button;
     XfpmNotify     *notify;
     
-    GtkWidget	   *osd;
     NotifyNotification *n;
     
-    
-    gulong	    destroy_id;
-    
     gboolean	    has_hw;
     gboolean	    on_battery;
     
-    glong            last_level;
-    glong 	    max_level;
+    gint32          last_level;
+    gint32 	    max_level;
     
     gboolean        dimmed;
     gboolean	    block;
@@ -86,9 +82,9 @@ xfpm_backlight_dim_brightness (XfpmBacklight *backlight)
 {
     gboolean ret;
     
-    if (xfpm_power_get_mode (backlight->priv->power) == XFPM_POWER_MODE_NORMAL )
+    if (xfpm_power_is_in_presentation_mode (backlight->priv->power) == FALSE )
     {
-	glong dim_level;
+	gint32 dim_level;
 	
 	g_object_get (G_OBJECT (backlight->priv->conf),
 		      backlight->priv->on_battery ? BRIGHTNESS_LEVEL_ON_BATTERY : BRIGHTNESS_LEVEL_ON_AC, &dim_level,
@@ -110,7 +106,7 @@ xfpm_backlight_dim_brightness (XfpmBacklight *backlight)
 	 **/
 	if (backlight->priv->last_level > dim_level)
 	{
-	    XFPM_DEBUG ("Current brightness level before dimming : %li, new %li", backlight->priv->last_level, dim_level);
+	    XFPM_DEBUG ("Current brightness level before dimming : %d, new %d", backlight->priv->last_level, dim_level);
 	    backlight->priv->dimmed = xfpm_brightness_set_level (backlight->priv->brightness, dim_level);
 	}
     }
@@ -123,12 +119,6 @@ xfpm_backlight_destroy_popup (gpointer data)
     
     backlight = XFPM_BACKLIGHT (data);
     
-    if ( backlight->priv->osd )
-    {
-	gtk_widget_destroy (backlight->priv->osd);
-	backlight->priv->osd = NULL;
-    }
-    
     if ( backlight->priv->n )
     {
 	g_object_unref (backlight->priv->n);
@@ -138,121 +128,44 @@ xfpm_backlight_destroy_popup (gpointer data)
     return FALSE;
 }
 
-static void
-xfpm_backlight_composited_changed_cb (XfpmBacklight *backlight)
-{
-    xfpm_backlight_destroy_popup (backlight);
-    xfpm_backlight_create_popup (backlight);
-}
-
 static void
 xfpm_backlight_show_notification (XfpmBacklight *backlight, gfloat value)
 {
-    gint i;
-    
-    static const char *display_icon_name[] = 
-    {
-	"notification-display-brightness-off",
-	"notification-display-brightness-low",
-	"notification-display-brightness-medium",
-	"notification-display-brightness-high",
-	"notification-display-brightness-full",
-	NULL
-    };
-    
+    gchar *summary;
+
+    /* create the notification on demand */
     if ( backlight->priv->n == NULL )
     {
-	backlight->priv->n = xfpm_notify_new_notification (backlight->priv->notify, 
-							   " ", 
-							   "", 
-							   NULL, 
-							   0, 
+	backlight->priv->n = xfpm_notify_new_notification (backlight->priv->notify,
+							   "",
+							   "",
+							   "xfpm-brightness-lcd",
+							   0,
 							   XFPM_NOTIFY_NORMAL,
 							   NULL);
     }
-    
-    i = (gint)value / 25;
-    
-    if ( i > 4 || i < 0 )
-	return;
-    
-    notify_notification_set_hint_int32  (backlight->priv->n,
-					 "value",
-					 value);
-    
-    notify_notification_set_hint_string (backlight->priv->n,
-					 "x-canonical-private-synchronous",
-					 "brightness");
-    
-    notify_notification_update (backlight->priv->n,
-			        " ",
-				"",
-				display_icon_name[i]);
-				
-    notify_notification_show (backlight->priv->n, NULL);
-}
 
-static void
-xfpm_backlight_create_popup (XfpmBacklight *backlight)
-{
-    if ( backlight->priv->osd != NULL )
-	return;
-	
-    backlight->priv->osd = gsd_media_keys_window_new ();
-    gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (backlight->priv->osd),
-					     XFPM_DISPLAY_BRIGHTNESS_ICON,
-					     TRUE);
-    gtk_window_set_position (GTK_WINDOW (backlight->priv->osd), GTK_WIN_POS_CENTER);
+    /* generate a human-readable summary for the notification */
+    summary = g_strdup_printf (_("Brightness: %.0f percent"), value);
+    notify_notification_update (backlight->priv->n, summary, NULL, NULL);
+    g_free (summary);
     
-    g_signal_connect_swapped (backlight->priv->osd, "composited-changed",
-			      G_CALLBACK (xfpm_backlight_composited_changed_cb), backlight);
-			      
+    /* add the brightness value to the notification */
+    notify_notification_set_hint_int32 (backlight->priv->n, "value", value);
+    
+    /* show the notification */
+    notify_notification_show (backlight->priv->n, NULL);
 }
 
 static void
 xfpm_backlight_show (XfpmBacklight *backlight, gint level)
 {
     gfloat value;
-    gboolean sync_notify;
-    gboolean show_popup;
     
     XFPM_DEBUG ("Level %u", level);
     
-    g_object_get (G_OBJECT (backlight->priv->conf),
-                  SHOW_BRIGHTNESS_POPUP, &show_popup,
-                  NULL);
-		  
-    if ( !show_popup )
-	goto out;
-    
-    g_object_get (G_OBJECT (backlight->priv->notify),
-		  "sync", &sync_notify,
-		  NULL);
-    
     value = (gfloat) 100 * level / backlight->priv->max_level;
-    
-    if ( !sync_notify ) /*Notification server doesn't support sync notifications*/
-    {
-	xfpm_backlight_create_popup (backlight);
-	gsd_media_keys_window_set_volume_level (GSD_MEDIA_KEYS_WINDOW (backlight->priv->osd),
-						round (value));
-	if ( !GTK_WIDGET_VISIBLE (backlight->priv->osd))
-	    gtk_window_present (GTK_WINDOW (backlight->priv->osd));
-    }
-    else
-    {
-	xfpm_backlight_show_notification (backlight, value);
-    }
-    
-    if ( backlight->priv->destroy_id != 0 )
-    {
-	g_source_remove (backlight->priv->destroy_id);
-	backlight->priv->destroy_id = 0;
-    }
-    
-out:
-    /* Release the memory after 60 seconds */
-    backlight->priv->destroy_id = g_timeout_add_seconds (60, (GSourceFunc) xfpm_backlight_destroy_popup, backlight);
+    xfpm_backlight_show_notification (backlight, value);
 }
 
 
@@ -274,7 +187,7 @@ xfpm_backlight_reset_cb (EggIdletime *idle, XfpmBacklight *backlight)
     {
 	if ( !backlight->priv->block)
 	{
-	    XFPM_DEBUG ("Alarm reset, setting level to %li", backlight->priv->last_level);
+	    XFPM_DEBUG ("Alarm reset, setting level to %d", backlight->priv->last_level);
 	    xfpm_brightness_set_level (backlight->priv->brightness, backlight->priv->last_level);
 	}
 	backlight->priv->dimmed = FALSE;
@@ -284,7 +197,7 @@ xfpm_backlight_reset_cb (EggIdletime *idle, XfpmBacklight *backlight)
 static void
 xfpm_backlight_button_pressed_cb (XfpmButton *button, XfpmButtonKey type, XfpmBacklight *backlight)
 {
-    glong level;
+    gint32 level;
     gboolean ret = TRUE;
     
     gboolean enable_brightness, show_popup;
@@ -294,22 +207,21 @@ xfpm_backlight_button_pressed_cb (XfpmButton *button, XfpmButtonKey type, XfpmBa
 		  SHOW_BRIGHTNESS_POPUP, &show_popup,
                   NULL);
     
-    if ( type == BUTTON_MON_BRIGHTNESS_UP )
+    if ( type != BUTTON_MON_BRIGHTNESS_UP && type != BUTTON_MON_BRIGHTNESS_DOWN )
+	return; /* sanity check, can this ever happen? */
+
+    backlight->priv->block = TRUE;
+    if ( !enable_brightness )
+	ret = xfpm_brightness_get_level (backlight->priv->brightness, &level);
+    else
     {
-	backlight->priv->block = TRUE;
-	if ( enable_brightness )
+	if ( type == BUTTON_MON_BRIGHTNESS_UP )
 	    ret = xfpm_brightness_up (backlight->priv->brightness, &level);
-	if ( ret && show_popup)
-	    xfpm_backlight_show (backlight, level);
-    }
-    else if ( type == BUTTON_MON_BRIGHTNESS_DOWN )
-    {
-	backlight->priv->block = TRUE;
-	if ( enable_brightness )
+	else
 	    ret = xfpm_brightness_down (backlight->priv->brightness, &level);
-	if ( ret && show_popup)
-	    xfpm_backlight_show (backlight, level);
     }
+    if ( ret && show_popup)
+	xfpm_backlight_show (backlight, level);
 }
 
 static void
@@ -386,7 +298,6 @@ xfpm_backlight_init (XfpmBacklight *backlight)
     backlight->priv->brightness = xfpm_brightness_new ();
     backlight->priv->has_hw     = xfpm_brightness_setup (backlight->priv->brightness);
     
-    backlight->priv->osd    = NULL;
     backlight->priv->notify = NULL;
     backlight->priv->idle   = NULL;
     backlight->priv->conf   = NULL;
@@ -394,7 +305,6 @@ xfpm_backlight_init (XfpmBacklight *backlight)
     backlight->priv->power    = NULL;
     backlight->priv->dimmed = FALSE;
     backlight->priv->block = FALSE;
-    backlight->priv->destroy_id = 0;
     
     if ( !backlight->priv->has_hw )
     {
