@@ -23,8 +23,12 @@
 #endif
 
 #include <stdio.h>
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -136,6 +140,7 @@ xfpm_dump (GHashTable *hash)
 	      "%s: %s\n"
 	      "%s: %s\n"
 	      "%s: %s\n"
+	      "%s: %s\n"
 	      "%s: %s\n",
 	     _("Can suspend"),
 	     xfpm_bool_to_local_string (can_suspend),
@@ -151,6 +156,8 @@ xfpm_dump (GHashTable *hash)
 	     xfpm_bool_to_local_string (can_shutdown),
 	     _("Authorized to spin down hard disks"),
 	     xfpm_bool_to_local_string (can_spin_down),
+	     _("Has battery"),
+	     xfpm_bool_to_local_string (has_battery),
 	     _("Has brightness panel"),
 	     xfpm_bool_to_local_string (has_lcd_brightness),
 	     _("Has power button"),
@@ -200,7 +207,7 @@ xfpm_start (DBusGConnection *bus, const gchar *client_id, gboolean dump)
     XFPM_DEBUG ("Starting the power manager");
     
     manager = xfpm_manager_new (bus, client_id);
-    
+
     if ( xfce_posix_signal_handler_init (&error)) 
     {
         xfce_posix_signal_handler_set_handler (SIGHUP,
@@ -235,7 +242,7 @@ xfpm_start (DBusGConnection *bus, const gchar *client_id, gboolean dump)
     gtk_main ();
     
     g_object_unref (manager);
-    
+
     exit (EXIT_SUCCESS);
 }
 
@@ -269,9 +276,11 @@ int main (int argc, char **argv)
 	{ NULL, },
     };
 
+#if !GLIB_CHECK_VERSION (2, 32, 0)
     if ( !g_thread_supported () )
 	g_thread_init (NULL);
-       
+#endif
+
     dbus_g_thread_init ();
 
     xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
