@@ -23,27 +23,39 @@
 #endif
 
 #include <stdio.h>
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
-
+#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-
-#if defined(__linux)
+#endif
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
+#endif
+#ifdef HAVE_SYS_SYSCTL_H
 #include <sys/sysctl.h>
+#endif
+#ifdef HAVE_SYS_USER_H
 #include <sys/user.h>
-#elif defined(__FreeBSD__)
+#endif
+
+#if defined(__FreeBSD__)
 #include <sys/stat.h>
 #elif defined(__SVR4) && defined(__sun)
 #include <fcntl.h>
 #include <procfs.h>
 #endif
 
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
+#endif
 
 #include <dbus/dbus-glib.h>
 
@@ -117,7 +129,7 @@ get_kinfo_proc (pid_t pid, struct kinfo_proc *p)
 static guint64
 get_start_time_for_pid (pid_t pid)
 {
-    guint64 start_time;
+    guint64 start_time = 0;
 #if defined(__linux)
     gchar *filename;
     gchar *contents;
@@ -240,7 +252,10 @@ xfpm_polkit_free_data (gpointer data)
 
     g_hash_table_destroy (polkit->priv->details);
     g_hash_table_destroy (polkit->priv->subject_hash);
+
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     g_value_array_free   (polkit->priv->subject);
+    G_GNUC_END_IGNORE_DEPRECATIONS
     
     polkit->priv->details      = NULL;
     polkit->priv->subject_hash = NULL;
@@ -343,8 +358,10 @@ xfpm_polkit_init_data (XfpmPolkit *polkit)
 	if ( G_LIKELY (start_time != 0 ) )
 	{
 	    GValue val = { 0 }, pid_val = { 0 }, start_time_val = { 0 };
-	    
+
+	    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	    polkit->priv->subject = g_value_array_new (2);
+	    G_GNUC_END_IGNORE_DEPRECATIONS
 	    polkit->priv->subject_hash = g_hash_table_new_full (g_str_hash, 
 								g_str_equal, 
 								g_free, 
@@ -352,7 +369,9 @@ xfpm_polkit_init_data (XfpmPolkit *polkit)
 	
 	    g_value_init (&val, G_TYPE_STRING);
 	    g_value_set_string (&val, "unix-process");
+	    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	    g_value_array_append (polkit->priv->subject, &val);
+	    G_GNUC_END_IGNORE_DEPRECATIONS
 	    
 	    g_value_unset (&val);
 	    
@@ -380,7 +399,9 @@ xfpm_polkit_init_data (XfpmPolkit *polkit)
 				       G_TYPE_VALUE));
     
     g_value_set_static_boxed (&hash_elem, polkit->priv->subject_hash);
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     g_value_array_append (polkit->priv->subject, &hash_elem);
+    G_GNUC_END_IGNORE_DEPRECATIONS
     
     /**
      * Polkit details, will leave it empty.
@@ -422,8 +443,10 @@ xfpm_polkit_check_auth_intern (XfpmPolkit *polkit, const gchar *action_id)
     
     g_return_val_if_fail (polkit->priv->proxy != NULL, FALSE);
     g_return_val_if_fail (polkit->priv->subject_valid, FALSE);
-     
+    
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     result = g_value_array_new (0);
+    G_GNUC_END_IGNORE_DEPRECATIONS
     
     ret = dbus_g_proxy_call (polkit->priv->proxy, "CheckAuthorization", &error,
 			     polkit->priv->subject_gtype, polkit->priv->subject,
@@ -451,7 +474,9 @@ xfpm_polkit_check_auth_intern (XfpmPolkit *polkit, const gchar *action_id)
 	g_error_free (error);
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     g_value_array_free (result);
+    G_GNUC_END_IGNORE_DEPRECATIONS
     
     XFPM_DEBUG ("Action=%s is authorized=%s", action_id, xfpm_bool_to_string (is_authorized));
     
