@@ -23,8 +23,12 @@
 #endif
 
 #include <stdio.h>
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 
 #include <glib.h>
 #include <libxfce4util/libxfce4util.h>
@@ -44,6 +48,7 @@ static void xfpm_xfconf_finalize   (GObject *object);
 struct XfpmXfconfPrivate
 {
     XfconfChannel 	*channel;
+    XfconfChannel   *session_channel;
     GValue              *values;
 };
 
@@ -79,10 +84,16 @@ enum
     PROP_IDLE_SLEEP_MODE,
     PROP_DIM_ON_AC_TIMEOUT,
     PROP_DIM_ON_BATTERY_TIMEOUT,
-    PROP_SPIN_DOWN_DISK_ON_AC,
-    PROP_SPIN_DOWN_DISK_ON_BATTERY,
+    PROP_SPIN_DOWN_DISK,
     PROP_SPIN_DOWN_DISK_ON_AC_TIMEOUT,
     PROP_SPIN_DOWN_DISK_ON_BATTERY_TIMEOUT,
+#ifdef WITH_NETWORK_MANAGER
+    PROP_NETWORK_MANAGER_SLEEP,
+#endif
+    PROP_LOGIND_HANDLE_POWER_KEY,
+    PROP_LOGIND_HANDLE_SUSPEND_KEY,
+    PROP_LOGIND_HANDLE_HIBERNATE_KEY,
+    PROP_LOGIND_HANDLE_LID_SWITCH,
     N_PROPERTIES
 };
 
@@ -180,11 +191,40 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
     if ( !g_str_has_prefix (property, PROPERTIES_PREFIX) || strlen (property) <= strlen (PROPERTIES_PREFIX) )
 	return;
 
-    XFPM_DEBUG("Property modified: %s\n", property);
+    /* We handle presentation mode in xfpm-power directly */
+    if ( g_strcmp0 (property, "/xfce4-power-manager/presentation-mode") == 0 )
+        return;
+
+    XFPM_DEBUG ("Property modified: %s\n", property);
     
     g_object_set_property (G_OBJECT (conf), property + strlen (PROPERTIES_PREFIX), value);
 }
 
+static void
+xfpm_xfsession_property_changed_cb (XfconfChannel *channel, gchar *property,
+				 GValue *value, XfpmXfconf *conf)
+{
+    /*FIXME: Set default for this key*/
+    if ( G_VALUE_TYPE(value) == G_TYPE_INVALID )
+        return;
+
+    XFPM_DEBUG ("property %s\n", property);
+
+    if ( g_strcmp0 (property, "/shutdown/LockScreen") != 0)
+        return;
+
+    /* sanity check */
+    if ( !G_VALUE_HOLDS (value, G_TYPE_BOOLEAN) )
+        return;
+
+    XFPM_DEBUG ("Property modified: %s\n", property);
+
+    /* update xfconf which will update xfpm and keep things in sync */
+    xfconf_channel_set_bool (conf->priv->channel,
+                             PROPERTIES_PREFIX LOCK_SCREEN_ON_SLEEP,
+                             g_value_get_boolean(value));
+}
+
 static void
 xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 {
@@ -430,7 +470,7 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                      PROP_DPMS_SLEEP_MODE,
                                      g_param_spec_string  (DPMS_SLEEP_MODE,
                                                            NULL, NULL,
-                                                           "standby",
+                                                           "Standby",
                                                            G_PARAM_READWRITE));
 #endif /* HAVE_DPMS */
 
@@ -492,23 +532,15 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
                                                         G_PARAM_READWRITE));
 
     /**
-     * XfpmXfconf::spin-down-on-ac
+     * XfpmXfconf::spin-down-hdd
      **/
     g_object_class_install_property (object_class,
-                                     PROP_SPIN_DOWN_DISK_ON_AC,
-                                     g_param_spec_boolean (SPIN_DOWN_ON_AC,
+                                     PROP_SPIN_DOWN_DISK,
+                                     g_param_spec_uint (SPIN_DOWN_HDD,
                                                            NULL, NULL,
-                                                           FALSE,
-                                                           G_PARAM_READWRITE));
-
-    /**
-     * XfpmXfconf::spin-down-on-battery
-     **/
-    g_object_class_install_property (object_class,
-                                     PROP_SPIN_DOWN_DISK_ON_BATTERY,
-                                     g_param_spec_boolean (SPIN_DOWN_ON_BATTERY,
-                                                           NULL, NULL,
-                                                           FALSE,
+							0,
+							G_MAXUINT16,
+							4,
                                                            G_PARAM_READWRITE));
 
     /**
@@ -535,6 +567,58 @@ xfpm_xfconf_class_init (XfpmXfconfClass *klass)
 							120,
                                                         G_PARAM_READWRITE));
 
+#ifdef WITH_NETWORK_MANAGER
+    /**
+     * XfpmXfconf::network-manager-sleep
+     **/
+    g_object_class_install_property (object_class,
+                                     PROP_NETWORK_MANAGER_SLEEP,
+                                     g_param_spec_boolean (NETWORK_MANAGER_SLEEP,
+                                                           NULL, NULL,
+                                                           TRUE,
+                                                           G_PARAM_READWRITE));
+#endif
+
+    /**
+     * XfpmXfconf::logind-handle-power-key
+     **/
+    g_object_class_install_property (object_class,
+                                     PROP_LOGIND_HANDLE_POWER_KEY,
+                                     g_param_spec_boolean (LOGIND_HANDLE_POWER_KEY,
+                                                           NULL, NULL,
+                                                           TRUE,
+                                                           G_PARAM_READWRITE));
+
+    /**
+     * XfpmXfconf::logind-handle-suspend-key
+     **/
+    g_object_class_install_property (object_class,
+                                     PROP_LOGIND_HANDLE_SUSPEND_KEY,
+                                     g_param_spec_boolean (LOGIND_HANDLE_SUSPEND_KEY,
+                                                           NULL, NULL,
+                                                           TRUE,
+                                                           G_PARAM_READWRITE));
+
+    /**
+     * XfpmXfconf::logind-handle-hibernate-key
+     **/
+    g_object_class_install_property (object_class,
+                                     PROP_LOGIND_HANDLE_HIBERNATE_KEY,
+                                     g_param_spec_boolean (LOGIND_HANDLE_HIBERNATE_KEY,
+                                                           NULL, NULL,
+                                                           TRUE,
+                                                           G_PARAM_READWRITE));
+
+    /**
+     * XfpmXfconf::logind-handle-lid-switch
+     **/
+    g_object_class_install_property (object_class,
+                                     PROP_LOGIND_HANDLE_LID_SWITCH,
+                                     g_param_spec_boolean (LOGIND_HANDLE_LID_SWITCH,
+                                                           NULL, NULL,
+                                                           TRUE,
+                                                           G_PARAM_READWRITE));
+
     g_type_class_add_private (klass, sizeof (XfpmXfconfPrivate));
 }
 
@@ -543,6 +627,7 @@ xfpm_xfconf_init (XfpmXfconf *conf)
 {
     GError *error = NULL;
     gboolean channel_valid;
+    gboolean lock_screen;
       
     conf->priv = XFPM_XFCONF_GET_PRIVATE (conf);
     
@@ -557,9 +642,27 @@ xfpm_xfconf_init (XfpmXfconf *conf)
     else
     {
 	conf->priv->channel = xfconf_channel_new ("xfce4-power-manager");
+    conf->priv->session_channel = xfconf_channel_new ("xfce4-session");
+
+    /* if xfce4-session is around, sync to it on startup */
+    if ( xfconf_channel_has_property (conf->priv->session_channel, "/shutdown/LockScreen") )
+    {
+        lock_screen = xfconf_channel_get_bool (conf->priv->session_channel,
+                                               "/shutdown/LockScreen",
+                                               TRUE);
+
+        XFPM_DEBUG("lock screen %s", lock_screen ? "TRUE" : "FALSE");
+
+        g_object_set (G_OBJECT (conf), LOCK_SCREEN_ON_SLEEP, lock_screen, NULL);
+    }
 
 	g_signal_connect (conf->priv->channel, "property-changed",
 			  G_CALLBACK (xfpm_xfconf_property_changed_cb), conf);
+
+    /* watch for session's property change so we can stay in sync */
+    g_signal_connect (conf->priv->session_channel, "property-changed",
+              G_CALLBACK (xfpm_xfsession_property_changed_cb), conf);
+
 	channel_valid = TRUE;
     }
     xfpm_xfconf_load (conf, channel_valid);
@@ -583,7 +686,10 @@ xfpm_xfconf_finalize(GObject *object)
     
     if (conf->priv->channel )
 	g_object_unref (conf->priv->channel);
-    
+
+    if (conf->priv->session_channel )
+        g_object_unref (conf->priv->session_channel);
+
     G_OBJECT_CLASS(xfpm_xfconf_parent_class)->finalize(object);
 }
 
